===============================
Xapo SDK & Tools
===============================

.. image:: https://badge.fury.io/py/xapo_sdk.png
    :target: http://badge.fury.io/py/xapo_sdk

.. image:: https://travis-ci.org/frepond/xapo_sdk.png?branch=master
        :target: https://travis-ci.org/frepond/xapo_sdk

.. image:: https://pypip.in/d/xapo_sdk/badge.png
        :target: https://pypi.python.org/pypi/xapo_sdk


Xapo's bitcoin sdk & tools

This is the Python version of the Xapo's Widget Tools. These tools allow you (Third Party Application, TPA) to easily embed tools like Payments Buttons, Donation Buttons and other kind of widgets as DIV or iFrame into your web application using your language of choice. In this way, tedious details like encryption and HTML snippet generation are handled for you in a simple and transparent way.


* Free software: BSD license
* Documentation: http://xapo-sdk.readthedocs.org.


Features
--------

* *Iframe* and *Div* HTML widgets snippet generator.